
# Type: negatively regulates




URI: [biolink:negatively_regulates](https://w3id.org/biolink/vocab/negatively_regulates)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [regulates](regulates.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | This is a grouping for process-process and entity-entity relations |

